@@ -71,7 +71,7 @@ def expdisk(scalerad=10, inc=60,fileName=None):
 
     # Create the cube
     cube = KinMS(xsize, ysize, vsize, cellsize, dv, beamsize, inc, sbProf=fx, sbRad=x, velProf=vel, intFlux=30,
-                 posAng=posang, gasSigma=10, huge_beam=False,fileName=fileName).model_cube(toplot=True)
+                 posAng=posang, gasSigma=10, huge_beam=False,fileName=fileName,ra=12,dec=10).model_cube(toplot=True)
 
     # If you want to change something about the plots, or save them directly to your disk, you can use the plotting
     # script separately:
